Module dynamic

Module dynamic 

Runtime-typed entity API for working with schemas that are not known at compile time.

Where the rest of SeaORM is statically typed around generated Entity / Model / Column types, this module exposes an Entity, Column, and Model that carry their schema information at runtime.

Unstable. The API in this module may change between minor versions.

Structs

Column
DynSelector
Entity
FieldType
FieldValue
Model
ModelType
SelectModelAndDynModel

Traits

DynSelectorTrait