pub enum BelongsTo<T>where
T: BelongsToCardinality,{
Unloaded,
Loaded(<T as BelongsToCardinality>::Loaded),
}Variants
Implementations
Sourceimpl<E> BelongsTo<E>where
E: EntityTrait,
impl<E> BelongsTo<E>where
E: EntityTrait,
Sourcepub fn into_option(self) -> Option<E::ModelEx>
pub fn into_option(self) -> Option<E::ModelEx>
Convert into an Option<ModelEx>
Sourceimpl<E> BelongsTo<Option<E>>where
E: EntityTrait,
impl<E> BelongsTo<Option<E>>where
E: EntityTrait,
Sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Return true if this optional relation was loaded and no model was found.
Sourcepub fn is_unloaded_or_not_found(&self) -> bool
pub fn is_unloaded_or_not_found(&self) -> bool
Return true if this optional relation holds no model โ i.e. it is either
Unloaded or was loaded with no match (is_not_found).
Sourcepub fn as_mut(&mut self) -> Option<&mut E::ModelEx>
pub fn as_mut(&mut self) -> Option<&mut E::ModelEx>
Get a mutable reference, if loaded with a model
Sourcepub fn into_option(self) -> Option<E::ModelEx>
pub fn into_option(self) -> Option<E::ModelEx>
Convert into an Option<ModelEx>
Sourceimpl<E> BelongsTo<E>
impl<E> BelongsTo<E>
pub fn into_active_model(self) -> ActiveBelongsTo<E>
Sourceimpl<E> BelongsTo<Option<E>>
impl<E> BelongsTo<Option<E>>
pub fn into_active_model(self) -> ActiveBelongsTo<Option<E>>