Struct sea_orm::entity::prelude::RelationDef [−][src]
pub struct RelationDef {
pub rel_type: RelationType,
pub from_tbl: TableRef,
pub to_tbl: TableRef,
pub from_col: Identity,
pub to_col: Identity,
pub is_owner: bool,
pub on_delete: Option<ForeignKeyAction>,
pub on_update: Option<ForeignKeyAction>,
}Expand description
Defines a relationship
Fields
rel_type: RelationTypeThe type of relationship defined in RelationType
from_tbl: TableRefReference from another Entity
to_tbl: TableRefReference to another ENtity
from_col: IdentityReference to from a Column
to_col: IdentityReference to another column
is_owner: boolDefines the owner of the Relation
on_delete: Option<ForeignKeyAction>Defines an operation to be performed on a Foreign Key when a
DELETE Operation is performed
on_update: Option<ForeignKeyAction>Defines an operation to be performed on a Foreign Key when a
UPDATE Operation is performed
Implementations