pub struct SeaRc;Expand description
A legacy namespace for compatibility.
Itโs needed, so that most existing SeaRc::new calls keep working.
This used to be an actual type
(a reference-counted pointer with special impls for dyn Iden contents).
Itโs not needed anymore.
Implementations
Sourceimpl SeaRc
impl SeaRc
Sourcepub fn new<I>(i: I) -> DynIdenwhere
I: Iden,
pub fn new<I>(i: I) -> DynIdenwhere
I: Iden,
A legacy method, kept for compatibility.
Nowadays, instead of wrapping an Iden object,
it eagerly โrendersโ it into a string and then drops the object.
Note that most Idens are statically known
and their representations arenโt actually โrenderedโ and allocated at runtime.
pub fn clone(iden: &DynIden) -> DynIden