IdentityOf

Trait IdentityOf 

pub trait IdentityOf<E>
where E: EntityTrait,
{ // Required method fn identity_of(self) -> Identity; }
Conversion into an Identity whose columns are guaranteed to belong to entity E. Used by RelationBuilder::from / to so the type system enforces that relation columns reference the right table.

Required Methods

fn identity_of(self) -> Identity

Build the Identity.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<E, C> IdentityOf<E> for (C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Source

impl<E, C> IdentityOf<E> for (C, C, C, C, C, C, C, C, C, C, C, C)
where E: EntityTrait<Column = C>, C: ColumnTrait,

Implementors

Source

impl<E, C> IdentityOf<E> for C
where E: EntityTrait<Column = C>, C: ColumnTrait,