pub enum DatabaseExecutor<'c> {
Connection(&'c DatabaseConnection),
Transaction(&'c DatabaseTransaction),
OwnedTransaction(DatabaseTransaction),
}Expand description
Either a borrowed DatabaseConnection / DatabaseTransaction, or an
owned DatabaseTransaction.
Implements ConnectionTrait and TransactionTrait, so APIs that
need to accept โany of those threeโ can take a DatabaseExecutor and
not worry about which variant the caller had. Used in particular by
sea-orm-migrationโs SchemaManager.
Variants
Connection(&'c DatabaseConnection)
Borrowed connection โ use against a long-lived pool.
Transaction(&'c DatabaseTransaction)
Borrowed transaction โ caller still owns the transaction handle.
OwnedTransaction(DatabaseTransaction)
Owned transaction โ used by migrationโs SchemaManager::begin() so
the transaction can be committed/rolled back at the end of the call.
Implementations
Sourceimpl DatabaseExecutor<'_>
impl DatabaseExecutor<'_>
Sourcepub async fn transaction_async<F, T, E>(
&self,
callback: F,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c DatabaseTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
pub async fn transaction_async<F, T, E>(
&self,
callback: F,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c DatabaseTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
Execute the function inside a transaction. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub async fn transaction_with_config_async<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c DatabaseTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
pub async fn transaction_with_config_async<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c DatabaseTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
Execute the function inside a transaction with isolation level and/or access mode. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub fn is_transaction(&self) -> bool
pub fn is_transaction(&self) -> bool
Returns true if this executor is backed by a transaction (borrowed or owned).
Sourcepub fn get_schema_builder(&self) -> SchemaBuilder
pub fn get_schema_builder(&self) -> SchemaBuilder
Creates a SchemaBuilder for this backend