pub enum SqliteTransactionMode {
Deferred,
Immediate,
Exclusive,
}Expand description
Which kind of transaction to start. Only supported by SQLite. https://www.sqlite.org/lang_transaction.html
Variants
Deferred
The default. Transaction starts when the next statement is executed, and will be a read or write transaction depending on that statement.
Immediate
Start a write transaction as soon as the BEGIN statement is received.
Exclusive
Start a write transaction as soon as the BEGIN statement is received. When in non-WAL mode, also block all other transactions from reading the database.
Implementations
Sourceimpl SqliteTransactionMode
impl SqliteTransactionMode
Sourcepub fn sqlite_keyword(&self) -> &'static str
pub fn sqlite_keyword(&self) -> &'static str
The keyword used to start a transaction in this mode (the word coming after โBEGINโ).