Insert

Struct Insert 

pub struct Insert<A>{ /* private fields */ }
Performs INSERT operations on a ActiveModel

Implementations

Source

impl<A> Insert<A>

pub fn exec<'a, C>( self, db: &'a C, ) -> impl Future<Output = Result<InsertResult<A>, DbErr>> + 'a
where C: ConnectionTrait, A: 'a,

Execute an insert operation

pub fn exec_without_returning<'a, C>( self, db: &'a C, ) -> impl Future<Output = Result<u64, DbErr>> + 'a
where <A::Entity as EntityTrait>::Model: IntoActiveModel<A>, C: ConnectionTrait, A: 'a,

Execute an insert operation without returning (donโ€™t use RETURNING syntax) Number of rows affected is returned

pub fn exec_with_returning<'a, C>( self, db: &'a C, ) -> impl Future<Output = Result<<A::Entity as EntityTrait>::Model, DbErr>> + 'a
where <A::Entity as EntityTrait>::Model: IntoActiveModel<A>, C: ConnectionTrait, A: 'a,

Execute an insert operation and return the inserted model (use RETURNING syntax if supported)

  • To get back all inserted models, use [exec_with_returning_many].
  • To get back all inserted primary keys, use [exec_with_returning_keys].
pub fn exec_with_returning_keys<'a, C>( self, db: &'a C, ) -> impl Future<Output = Result<Vec<<<<A as ActiveModelTrait>::Entity as EntityTrait>::PrimaryKey as PrimaryKeyTrait>::ValueType>, DbErr>> + 'a
where <A::Entity as EntityTrait>::Model: IntoActiveModel<A>, C: ConnectionTrait, A: 'a,

Execute an insert operation and return primary keys of inserted models

Panics

Panics if the database backend does not support INSERT RETURNING.

pub fn exec_with_returning_many<'a, C>( self, db: &'a C, ) -> impl Future<Output = Result<Vec<<A::Entity as EntityTrait>::Model>, DbErr>> + 'a
where <A::Entity as EntityTrait>::Model: IntoActiveModel<A>, C: ConnectionTrait, A: 'a,

Execute an insert operation and return all inserted models

Panics

Panics if the database backend does not support INSERT RETURNING.

Source

impl<A> Insert<A>

pub fn one<M>(m: M) -> Self
where M: IntoActiveModel<A>,

Insert one Model or ActiveModel

Model

use sea_orm::{entity::*, query::*, tests_cfg::cake, DbBackend};

assert_eq!(
    Insert::one(cake::Model {
        id: 1,
        name: "Apple Pie".to_owned(),
    })
    .build(DbBackend::Postgres)
    .to_string(),
    r#"INSERT INTO "cake" ("id", "name") VALUES (1, 'Apple Pie')"#,
);

ActiveModel

use sea_orm::{entity::*, query::*, tests_cfg::cake, DbBackend};

assert_eq!(
    Insert::one(cake::ActiveModel {
        id: NotSet,
        name: Set("Apple Pie".to_owned()),
    })
    .build(DbBackend::Postgres)
    .to_string(),
    r#"INSERT INTO "cake" ("name") VALUES ('Apple Pie')"#,
);
pub fn many<M, I>(models: I) -> Self
where M: IntoActiveModel<A>, I: IntoIterator<Item = M>,

Insert many Model or ActiveModel

use sea_orm::{entity::*, query::*, tests_cfg::cake, DbBackend};

assert_eq!(
    Insert::many([
        cake::Model {
            id: 1,
            name: "Apple Pie".to_owned(),
        },
        cake::Model {
            id: 2,
            name: "Orange Scone".to_owned(),
        }
    ])
    .build(DbBackend::Postgres)
    .to_string(),
    r#"INSERT INTO "cake" ("id", "name") VALUES (1, 'Apple Pie'), (2, 'Orange Scone')"#,
);
pub fn add<M>(self, m: M) -> Self
where M: IntoActiveModel<A>,

Add a Model to Self

Panics

Panics if the rows have different column sets from whatโ€™ve previously been cached in the query statement

pub fn add_multi<M, I>(self, models: I) -> Self
where M: IntoActiveModel<A>, I: IntoIterator<Item = M>,

๐Ÿ‘ŽDeprecated since 1.1.3:

Please use Insert::add_many which does not panic

Add many Models to Self. This is the legacy implementation priori to 1.1.3.

Panics

Panics if the rows have different column sets

pub fn add_many<M, I>(self, models: I) -> Self
where M: IntoActiveModel<A>, I: IntoIterator<Item = M>,

Add many Models to Self

pub fn on_conflict(self, on_conflict: OnConflict) -> Self

On conflict

on conflict do nothing

use sea_orm::{entity::*, query::*, sea_query::OnConflict, tests_cfg::cake, DbBackend};

let orange = cake::ActiveModel {
    id: ActiveValue::set(2),
    name: ActiveValue::set("Orange".to_owned()),
};
assert_eq!(
    cake::Entity::insert(orange)
        .on_conflict(
            OnConflict::column(cake::Column::Name)
                .do_nothing()
                .to_owned()
        )
        .build(DbBackend::Postgres)
        .to_string(),
    r#"INSERT INTO "cake" ("id", "name") VALUES (2, 'Orange') ON CONFLICT ("name") DO NOTHING"#,
);

on conflict do update

use sea_orm::{entity::*, query::*, sea_query::OnConflict, tests_cfg::cake, DbBackend};

let orange = cake::ActiveModel {
    id: ActiveValue::set(2),
    name: ActiveValue::set("Orange".to_owned()),
};
assert_eq!(
    cake::Entity::insert(orange)
        .on_conflict(
            OnConflict::column(cake::Column::Name)
                .update_column(cake::Column::Name)
                .to_owned()
        )
        .build(DbBackend::Postgres)
        .to_string(),
    r#"INSERT INTO "cake" ("id", "name") VALUES (2, 'Orange') ON CONFLICT ("name") DO UPDATE SET "name" = "excluded"."name""#,
);
pub fn do_nothing(self) -> TryInsert<A>

Allow insert statement to return without error if nothingโ€™s been inserted

pub fn on_empty_do_nothing(self) -> TryInsert<A>

Alias to do_nothing

pub fn on_conflict_do_nothing(self) -> TryInsert<A>

Set ON CONFLICT on primary key do nothing, but with MySQL specific polyfill.

use sea_orm::{entity::*, query::*, sea_query::OnConflict, tests_cfg::cake, DbBackend};

let orange = cake::ActiveModel {
    id: ActiveValue::set(2),
    name: ActiveValue::set("Orange".to_owned()),
};

assert_eq!(
    cake::Entity::insert(orange.clone())
        .on_conflict_do_nothing()
        .build(DbBackend::MySql)
        .to_string(),
    r#"INSERT INTO `cake` (`id`, `name`) VALUES (2, 'Orange') ON DUPLICATE KEY UPDATE `id` = `id`"#,
);
assert_eq!(
    cake::Entity::insert(orange.clone())
        .on_conflict_do_nothing()
        .build(DbBackend::Postgres)
        .to_string(),
    r#"INSERT INTO "cake" ("id", "name") VALUES (2, 'Orange') ON CONFLICT ("id") DO NOTHING"#,
);
assert_eq!(
    cake::Entity::insert(orange)
        .on_conflict_do_nothing()
        .build(DbBackend::Sqlite)
        .to_string(),
    r#"INSERT INTO "cake" ("id", "name") VALUES (2, 'Orange') ON CONFLICT ("id") DO NOTHING"#,
);