pub struct UpdateOne<A: ActiveModelTrait>(/* private fields */);Expand description
A request to update an ActiveModel.
The primary key must be set.
Otherwise, it’s impossible to generate the SQL condition and find the record.
In that case, exec will return an error and not send any queries to the database.
If you want to use QueryTrait and access the generated SQL query,
you need to convert into ValidatedUpdateOne first.
Implementations
Sourceimpl<A> UpdateOne<A>where
A: ActiveModelTrait,
impl<A> UpdateOne<A>where
A: ActiveModelTrait,
Sourcepub fn exec_without_returning<C>(self, db: &C) -> Result<UpdateResult, DbErr>where
C: ConnectionTrait,
pub fn exec_without_returning<C>(self, db: &C) -> Result<UpdateResult, DbErr>where
C: ConnectionTrait,
Execute an UPDATE operation without a RETURNING clause, yielding an
UpdateResult instead of the updated model. Returns
DbErr::RecordNotUpdated if no row matches.
Sourceimpl<A: ActiveModelTrait> UpdateOne<A>
impl<A: ActiveModelTrait> UpdateOne<A>
Sourcepub fn validate(self) -> Result<ValidatedUpdateOne<A>, DbErr>
pub fn validate(self) -> Result<ValidatedUpdateOne<A>, DbErr>
Check whether the primary key is set and we can proceed with the operation.