DatabaseConnection

Struct DatabaseConnection 

#[non_exhaustive]
pub struct DatabaseConnection { pub inner: DatabaseConnectionType, /* private fields */ }
A handle to a database — implements ConnectionTrait and TransactionTrait so it works with every query and mutation method in SeaORM.

Behind the scenes this is a connection pool (for SQLx-backed drivers) or a shared connection (for rusqlite / mocks / proxies), so it is cheap to clone — pass &DbConn around or db.clone() into spawned tasks. Obtain one via Database::connect.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
inner: DatabaseConnectionType

Driver-specific connection or pool. Held in a field so we can attach orthogonal state (e.g. RBAC) alongside.

Implementations

Source

impl DatabaseConnection

pub fn as_mock_connection(&self) -> &MockDatabaseConnection

Available on crate feature mock only.

Generate a database connection for testing the Mock database

Panics

Panics if DbConn is not a mock connection.

pub fn into_transaction_log(self) -> Vec<Transaction>

Available on crate feature mock only.

Get the transaction log as a collection Vec<crate::Transaction>

Panics

Panics if the mocker mutex is being held by another thread.

Source

impl DatabaseConnection

pub fn as_proxy_connection(&self) -> &ProxyDatabaseConnection

Available on crate feature proxy only.

Generate a database connection for testing the Proxy database

Panics

Panics if DbConn is not a proxy connection.

Source

impl DatabaseConnection

pub fn load_rbac(&self) -> Result<(), DbErr>

Available on crate feature rbac only.

Load RBAC data from the same database as this connection and setup RBAC engine. If the RBAC engine already exists, it will be replaced.

pub fn load_rbac_from(&self, db: &DbConn) -> Result<(), DbErr>

Available on crate feature rbac only.

Load RBAC data from the given database connection and setup RBAC engine. This could be from another database.

pub fn replace_rbac(&self, engine: RbacEngine)

Available on crate feature rbac only.

Replace the internal RBAC engine.

pub fn restricted_for( &self, user_id: RbacUserId, ) -> Result<RestrictedConnection, DbErr>

Available on crate feature rbac only.

Create a restricted connection with access control specific for the user.

Source

impl DatabaseConnection

pub fn transaction<F, T, E>( &self, callback: F, ) -> Result<T, TransactionError<E>>
where F: for<'c> FnOnce(&'c DatabaseTransaction) -> Result<T, E>, E: Display + Debug,

Execute the function inside a transaction. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.

pub fn transaction_with_config<F, T, E>( &self, callback: F, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<T, TransactionError<E>>
where F: for<'c> FnOnce(&'c DatabaseTransaction) -> Result<T, E>, E: Display + Debug,

Execute the function inside a transaction with isolation level and/or access mode. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.

pub fn get_database_backend(&self) -> DbBackend

Get the database backend for this connection

Panics

Panics if DatabaseConnection is Disconnected.

pub fn get_schema_builder(&self) -> SchemaBuilder

Creates a SchemaBuilder for this backend

pub fn set_metric_callback<F>(&mut self, _callback: F)
where F: Fn(&Info<'_>) + 'static,

Sets a callback to metric this connection

pub fn ping(&self) -> Result<(), DbErr>

Checks if a connection to the database is still valid.

pub fn close(self) -> Result<(), DbErr>

Explicitly close the database connection. See Self::close_by_ref for usage with references.

pub fn close_by_ref(&self) -> Result<(), DbErr>

Explicitly close the database connection