pub struct SelectGetableValue<T, C>{ /* private fields */ }Expand description
SelectorTrait adapter that decodes each row as a tuple T whose
columns are addressed by the iden enum C (rather than positionally).