CursorTrait

Trait CursorTrait 

pub trait CursorTrait {
    type Selector: SelectorTrait;
}
Extension trait that adds .cursor_by(...) to anything that can be paginated with a keyset cursor — implemented for Select, SelectTwo, SelectThree.

Required Associated Types

type Selector: SelectorTrait

The SelectorTrait used to materialise each row of the cursor.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E, F, G, M, N, O, TOP> CursorTrait for SelectThree<E, F, G, TOP>
where E: EntityTrait<Model = M>, F: EntityTrait<Model = N>, G: EntityTrait<Model = O>, M: FromQueryResult + Sized, N: FromQueryResult + Sized, O: FromQueryResult + Sized, TOP: Topology,

Source

impl<E, F, M, N> CursorTrait for SelectTwo<E, F>
where E: EntityTrait<Model = M>, F: EntityTrait<Model = N>, M: FromQueryResult + Sized, N: FromQueryResult + Sized,

Source

impl<E, M> CursorTrait for Select<E>
where E: EntityTrait<Model = M>, M: FromQueryResult + Sized,