pub enum IpNetwork {
V4(Ipv4Network),
V6(Ipv6Network),
}with-ipnetwork only.Expand description
Represents a generic network range. This type can have two variants: the v4 and the v6 case.
Variants
V4(Ipv4Network)
V6(Ipv6Network)
Implementations
Sourceimpl IpNetwork
impl IpNetwork
Sourcepub fn new(ip: IpAddr, prefix: u8) -> Result<IpNetwork, IpNetworkError>
pub fn new(ip: IpAddr, prefix: u8) -> Result<IpNetwork, IpNetworkError>
Constructs a new IpNetwork from a given IpAddr and a prefix denoting the
network size. If the prefix is larger than 32 (for IPv4) or 128 (for IPv6), this
will raise an IpNetworkError::InvalidPrefix error. Support for IPv6 is not
complete yet.
Sourcepub fn with_netmask(
netaddr: IpAddr,
netmask: IpAddr,
) -> Result<IpNetwork, IpNetworkError>
pub fn with_netmask( netaddr: IpAddr, netmask: IpAddr, ) -> Result<IpNetwork, IpNetworkError>
Constructs a new IpNetwork from a network address and a network mask.
If the netmask is not valid this will return an IpNetworkError::InvalidPrefix.
Sourcepub fn prefix(&self) -> u8
pub fn prefix(&self) -> u8
Returns the prefix of the given IpNetwork
Example
use ipnetwork::IpNetwork;
assert_eq!(IpNetwork::V4("10.9.0.1".parse().unwrap()).prefix(), 32u8);
assert_eq!(IpNetwork::V4("10.9.0.32/16".parse().unwrap()).prefix(), 16u8);
assert_eq!(IpNetwork::V6("ff01::0".parse().unwrap()).prefix(), 128u8);
assert_eq!(IpNetwork::V6("ff01::0/32".parse().unwrap()).prefix(), 32u8);Sourcepub fn network(&self) -> IpAddr
pub fn network(&self) -> IpAddr
Returns the address of the network denoted by this IpNetwork.
This means the lowest possible IP address inside of the network.
Examples
use std::net::{Ipv4Addr, Ipv6Addr};
use ipnetwork::IpNetwork;
let net: IpNetwork = "10.1.9.32/16".parse().unwrap();
assert_eq!(net.network(), Ipv4Addr::new(10, 1, 0, 0));
let net: IpNetwork = "2001:db8::/96".parse().unwrap();
assert_eq!(net.network(), Ipv6Addr::new(0x2001, 0xdb8, 0, 0, 0, 0, 0, 0));Sourcepub fn broadcast(&self) -> IpAddr
pub fn broadcast(&self) -> IpAddr
Returns the broadcasting address of this IpNetwork.
This means the highest possible IP address inside of the network.
Examples
use std::net::Ipv4Addr;
use ipnetwork::{IpNetwork, Ipv4Network};
let net: Ipv4Network = "10.9.0.32/16".parse().unwrap();
assert_eq!(net.broadcast(), Ipv4Addr::new(10, 9, 255, 255));Sourcepub fn mask(&self) -> IpAddr
pub fn mask(&self) -> IpAddr
Returns the mask for this IpNetwork.
That means the prefix most significant bits will be 1 and the rest 0
Example
use ipnetwork::IpNetwork;
use std::net::{Ipv4Addr, Ipv6Addr};
let v4_net: IpNetwork = "10.9.0.1".parse().unwrap();
assert_eq!(v4_net.mask(), Ipv4Addr::new(255, 255, 255, 255));
let v4_net: IpNetwork = "10.9.0.32/16".parse().unwrap();
assert_eq!(v4_net.mask(), Ipv4Addr::new(255, 255, 0, 0));
let v6_net: IpNetwork = "ff01::0".parse().unwrap();
assert_eq!(v6_net.mask(), Ipv6Addr::new(0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff));
let v6_net: IpNetwork = "ff01::0/32".parse().unwrap();
assert_eq!(v6_net.mask(), Ipv6Addr::new(0xffff, 0xffff, 0, 0, 0, 0, 0, 0));Sourcepub fn is_ipv4(&self) -> bool
pub fn is_ipv4(&self) -> bool
Returns true if the IP in this IpNetwork is a valid IPv4 address,
false if it’s a valid IPv6 address.
Example
use ipnetwork::IpNetwork;
let v4: IpNetwork = IpNetwork::V4("10.9.0.32/16".parse().unwrap());
assert_eq!(v4.is_ipv4(), true);
assert_eq!(v4.is_ipv6(), false);Sourcepub fn is_ipv6(&self) -> bool
pub fn is_ipv6(&self) -> bool
Returns true if the IP in this IpNetwork is a valid IPv6 address,
false if it’s a valid IPv4 address.
Example
use ipnetwork::IpNetwork;
let v6: IpNetwork = IpNetwork::V6("ff01::0/32".parse().unwrap());
assert_eq!(v6.is_ipv6(), true);
assert_eq!(v6.is_ipv4(), false);Sourcepub fn contains(&self, ip: IpAddr) -> bool
pub fn contains(&self, ip: IpAddr) -> bool
Checks if a given IpAddr is in this IpNetwork
Examples
use std::net::IpAddr;
use ipnetwork::IpNetwork;
let net: IpNetwork = "127.0.0.0/24".parse().unwrap();
let ip1: IpAddr = "127.0.0.1".parse().unwrap();
let ip2: IpAddr = "172.0.0.1".parse().unwrap();
let ip4: IpAddr = "::1".parse().unwrap();
assert!(net.contains(ip1));
assert!(!net.contains(ip2));
assert!(!net.contains(ip4));Sourcepub fn size(&self) -> NetworkSize
pub fn size(&self) -> NetworkSize
Returns the number of possible host addresses in this IpAddr
Examples
use ipnetwork::{IpNetwork, NetworkSize};
let net: IpNetwork = "127.0.0.0/24".parse().unwrap();
assert_eq!(net.size(), NetworkSize::V4(256))Sourcepub fn iter(&self) -> IpNetworkIterator ⓘ
pub fn iter(&self) -> IpNetworkIterator ⓘ
Returns an iterator over the addresses contained in the network.
This lists all the addresses in the network range, in ascending order.