pub struct TimeDate { /* private fields */ }Expand description
Calendar date.
Years between -100_000 and +100_000 inclusive are guaranteed to be
representable. Any values outside this range may have incidental support
that can change at any time without notice. If you need support outside this
range, please file an issue
with your use case.
Implementations
sourceimpl Date
impl Date
sourcepub const fn try_from_ymd(
year: i32,
month: u8,
day: u8
) -> Result<Date, ComponentRange>
pub const fn try_from_ymd(
year: i32,
month: u8,
day: u8
) -> Result<Date, ComponentRange>
Attempt to create a Date from the year, month, and day.
assert!(Date::try_from_ymd(2019, 1, 1).is_ok());
assert!(Date::try_from_ymd(2019, 12, 31).is_ok());Returns None if the date is not valid.
assert!(Date::try_from_ymd(2019, 2, 29).is_err()); // 2019 isn't a leap year.This function is const fn when using rustc >= 1.46.
sourcepub const fn try_from_yo(
year: i32,
ordinal: u16
) -> Result<Date, ComponentRange>
pub const fn try_from_yo(
year: i32,
ordinal: u16
) -> Result<Date, ComponentRange>
Attempt to create a Date from the year and ordinal day number.
assert!(Date::try_from_yo(2019, 1).is_ok());
assert!(Date::try_from_yo(2019, 365).is_ok());Returns None if the date is not valid.
assert!(Date::try_from_yo(2019, 366).is_err()); // 2019 isn't a leap year.This function is const fn when using rustc >= 1.46.
sourcepub const fn try_from_iso_ywd(
year: i32,
week: u8,
weekday: Weekday
) -> Result<Date, ComponentRange>
pub const fn try_from_iso_ywd(
year: i32,
week: u8,
weekday: Weekday
) -> Result<Date, ComponentRange>
Attempt to create a Date from the ISO year, week, and weekday.
assert!(Date::try_from_iso_ywd(2019, 1, Monday).is_ok());
assert!(Date::try_from_iso_ywd(2019, 1, Tuesday).is_ok());
assert!(Date::try_from_iso_ywd(2020, 53, Friday).is_ok());Returns None if the week is not valid.
assert!(Date::try_from_iso_ywd(2019, 53, Monday).is_err()); // 2019 doesn't have 53 weeks.This function is const fn when using rustc >= 1.46.
sourcepub fn today() -> Date
👎 Deprecated since 0.2.7: This method returns a value that assumes an offset of UTC.
pub fn today() -> Date
This method returns a value that assumes an offset of UTC.
Create a Date representing the current date.
assert!(Date::today().year() >= 2019);sourcepub const fn year(self) -> i32
pub const fn year(self) -> i32
Get the year of the date.
assert_eq!(date!(2019-01-01).year(), 2019);
assert_eq!(date!(2019-12-31).year(), 2019);
assert_eq!(date!(2020-01-01).year(), 2020);This function is const fn when using rustc >= 1.46.
sourcepub const fn month(self) -> u8
pub const fn month(self) -> u8
Get the month. If fetching both the month and day, it is more efficient
to use Date::month_day.
The returned value will always be in the range 1..=12.
assert_eq!(date!(2019-01-01).month(), 1);
assert_eq!(date!(2019-12-31).month(), 12);This function is const fn when using rustc >= 1.46.
sourcepub const fn day(self) -> u8
pub const fn day(self) -> u8
Get the day of the month. If fetching both the month and day, it is more
efficient to use Date::month_day.
The returned value will always be in the range 1..=31.
assert_eq!(date!(2019-01-01).day(), 1);
assert_eq!(date!(2019-12-31).day(), 31);This function is const fn when using rustc >= 1.46.
sourcepub const fn month_day(self) -> (u8, u8)
pub const fn month_day(self) -> (u8, u8)
Get the month and day. This is more efficient than fetching the components individually.
The month component will always be in the range 1..=12;
the day component in 1..=31.
assert_eq!(date!(2019-01-01).month_day(), (1, 1));
assert_eq!(date!(2019-12-31).month_day(), (12, 31));This function is const fn when using rustc >= 1.46.
sourcepub const fn ordinal(self) -> u16
pub const fn ordinal(self) -> u16
Get the day of the year.
The returned value will always be in the range 1..=366 (1..=365 for
common years).
assert_eq!(date!(2019-01-01).ordinal(), 1);
assert_eq!(date!(2019-12-31).ordinal(), 365);This function is const fn when using rustc >= 1.46.
sourcepub const fn iso_year_week(self) -> (i32, u8)
pub const fn iso_year_week(self) -> (i32, u8)
Get the ISO 8601 year and week number.
assert_eq!(date!(2019-01-01).iso_year_week(), (2019, 1));
assert_eq!(date!(2019-10-04).iso_year_week(), (2019, 40));
assert_eq!(date!(2020-01-01).iso_year_week(), (2020, 1));
assert_eq!(date!(2020-12-31).iso_year_week(), (2020, 53));
assert_eq!(date!(2021-01-01).iso_year_week(), (2020, 53));This function is const fn when using rustc >= 1.46.
sourcepub const fn week(self) -> u8
pub const fn week(self) -> u8
Get the ISO week number.
The returned value will always be in the range 1..=53.
assert_eq!(date!(2019-01-01).week(), 1);
assert_eq!(date!(2019-10-04).week(), 40);
assert_eq!(date!(2020-01-01).week(), 1);
assert_eq!(date!(2020-12-31).week(), 53);
assert_eq!(date!(2021-01-01).week(), 53);This function is const fn when using rustc >= 1.46.
sourcepub const fn sunday_based_week(self) -> u8
pub const fn sunday_based_week(self) -> u8
Get the week number where week 1 begins on the first Sunday.
The returned value will always be in the range 0..=53.
assert_eq!(date!(2019-01-01).sunday_based_week(), 0);
assert_eq!(date!(2020-01-01).sunday_based_week(), 0);
assert_eq!(date!(2020-12-31).sunday_based_week(), 52);
assert_eq!(date!(2021-01-01).sunday_based_week(), 0);This function is const fn when using rustc >= 1.46.
sourcepub const fn monday_based_week(self) -> u8
pub const fn monday_based_week(self) -> u8
Get the week number where week 1 begins on the first Monday.
The returned value will always be in the range 0..=53.
assert_eq!(date!(2019-01-01).monday_based_week(), 0);
assert_eq!(date!(2020-01-01).monday_based_week(), 0);
assert_eq!(date!(2020-12-31).monday_based_week(), 52);
assert_eq!(date!(2021-01-01).monday_based_week(), 0);This function is const fn when using rustc >= 1.46.
sourcepub const fn as_ymd(self) -> (i32, u8, u8)
pub const fn as_ymd(self) -> (i32, u8, u8)
Get the year, month, and day.
assert_eq!(date!(2019-01-01).as_ymd(), (2019, 1, 1));This function is const fn when using rustc >= 1.46.
sourcepub const fn as_yo(self) -> (i32, u16)
pub const fn as_yo(self) -> (i32, u16)
Get the year and ordinal day number.
assert_eq!(date!(2019-01-01).as_yo(), (2019, 1));This function is const fn when using rustc >= 1.46.
sourcepub fn weekday(self) -> Weekday
pub fn weekday(self) -> Weekday
Get the weekday.
This current uses Zeller’s congruence internally.
assert_eq!(date!(2019-01-01).weekday(), Tuesday);
assert_eq!(date!(2019-02-01).weekday(), Friday);
assert_eq!(date!(2019-03-01).weekday(), Friday);
assert_eq!(date!(2019-04-01).weekday(), Monday);
assert_eq!(date!(2019-05-01).weekday(), Wednesday);
assert_eq!(date!(2019-06-01).weekday(), Saturday);
assert_eq!(date!(2019-07-01).weekday(), Monday);
assert_eq!(date!(2019-08-01).weekday(), Thursday);
assert_eq!(date!(2019-09-01).weekday(), Sunday);
assert_eq!(date!(2019-10-01).weekday(), Tuesday);
assert_eq!(date!(2019-11-01).weekday(), Friday);
assert_eq!(date!(2019-12-01).weekday(), Sunday);sourcepub fn next_day(self) -> Date
pub fn next_day(self) -> Date
Get the next calendar date.
assert_eq!(date!(2019-01-01).next_day(), date!(2019-01-02));
assert_eq!(date!(2019-01-31).next_day(), date!(2019-02-01));
assert_eq!(date!(2019-12-31).next_day(), date!(2020-01-01));sourcepub fn previous_day(self) -> Date
pub fn previous_day(self) -> Date
Get the previous calendar date.
assert_eq!(date!(2019-01-02).previous_day(), date!(2019-01-01));
assert_eq!(date!(2019-02-01).previous_day(), date!(2019-01-31));
assert_eq!(date!(2020-01-01).previous_day(), date!(2019-12-31));sourcepub const fn julian_day(self) -> i64
pub const fn julian_day(self) -> i64
Get the Julian day for the date.
The algorithm to perform this conversion is derived from one provided by Peter Baum; it is freely available here.
assert_eq!(date!(-4713-11-24).julian_day(), 0);
assert_eq!(date!(2000-01-01).julian_day(), 2_451_545);
assert_eq!(date!(2019-01-01).julian_day(), 2_458_485);
assert_eq!(date!(2019-12-31).julian_day(), 2_458_849);This function is const fn when using rustc >= 1.46.
sourcepub fn from_julian_day(julian_day: i64) -> Date
pub fn from_julian_day(julian_day: i64) -> Date
Create a Date from the Julian day.
The algorithm to perform this conversion is derived from one provided by Peter Baum; it is freely available here.
assert_eq!(
Date::from_julian_day(0),
date!(-4713-11-24)
);
assert_eq!(Date::from_julian_day(2_451_545), date!(2000-01-01));
assert_eq!(Date::from_julian_day(2_458_485), date!(2019-01-01));
assert_eq!(Date::from_julian_day(2_458_849), date!(2019-12-31));sourceimpl Date
impl Date
Methods to add a Time component, resulting in a PrimitiveDateTime.
sourcepub const fn midnight(self) -> PrimitiveDateTime
pub const fn midnight(self) -> PrimitiveDateTime
Create a PrimitiveDateTime using the existing date. The Time component will
be set to midnight.
assert_eq!(
date!(1970-01-01).midnight(),
date!(1970-01-01).with_time(time!(0:00))
);sourcepub const fn with_time(self, time: Time) -> PrimitiveDateTime
pub const fn with_time(self, time: Time) -> PrimitiveDateTime
Create a PrimitiveDateTime using the existing date and the provided Time.
assert_eq!(
date!(1970-01-01).with_time(time!(0:00)),
date!(1970-01-01).midnight(),
);sourcepub const fn try_with_hms(
self,
hour: u8,
minute: u8,
second: u8
) -> Result<PrimitiveDateTime, ComponentRange>
pub const fn try_with_hms(
self,
hour: u8,
minute: u8,
second: u8
) -> Result<PrimitiveDateTime, ComponentRange>
Attempt to create a PrimitiveDateTime using the existing date and the
provided time.
assert!(date!(1970-01-01).try_with_hms(0, 0, 0).is_ok());
assert!(date!(1970-01-01).try_with_hms(24, 0, 0).is_err());This function is const fn when using rustc >= 1.46.
sourcepub const fn try_with_hms_milli(
self,
hour: u8,
minute: u8,
second: u8,
millisecond: u16
) -> Result<PrimitiveDateTime, ComponentRange>
pub const fn try_with_hms_milli(
self,
hour: u8,
minute: u8,
second: u8,
millisecond: u16
) -> Result<PrimitiveDateTime, ComponentRange>
Attempt to create a PrimitiveDateTime using the existing date and the provided time.
assert!(date!(1970-01-01).try_with_hms_milli(0, 0, 0, 0).is_ok());
assert!(date!(1970-01-01).try_with_hms_milli(24, 0, 0, 0).is_err());This function is const fn when using rustc >= 1.46.
sourcepub const fn try_with_hms_micro(
self,
hour: u8,
minute: u8,
second: u8,
microsecond: u32
) -> Result<PrimitiveDateTime, ComponentRange>
pub const fn try_with_hms_micro(
self,
hour: u8,
minute: u8,
second: u8,
microsecond: u32
) -> Result<PrimitiveDateTime, ComponentRange>
Attempt to create a PrimitiveDateTime using the existing date and the
provided time.
assert!(date!(1970-01-01)
.try_with_hms_micro(0, 0, 0, 0)
.is_ok());
assert!(date!(1970-01-01)
.try_with_hms_micro(24, 0, 0, 0)
.is_err());This function is const fn when using rustc >= 1.46.
sourcepub const fn try_with_hms_nano(
self,
hour: u8,
minute: u8,
second: u8,
nanosecond: u32
) -> Result<PrimitiveDateTime, ComponentRange>
pub const fn try_with_hms_nano(
self,
hour: u8,
minute: u8,
second: u8,
nanosecond: u32
) -> Result<PrimitiveDateTime, ComponentRange>
Attempt to create a PrimitiveDateTime using the existing date and the provided time.
assert!(date!(1970-01-01).try_with_hms_nano(0, 0, 0, 0).is_ok());
assert!(date!(1970-01-01).try_with_hms_nano(24, 0, 0, 0).is_err());This function is const fn when using rustc >= 1.46.
sourceimpl Date
impl Date
Methods that allow formatting the Date.
sourcepub fn format(self, format: impl AsRef<str>) -> String
pub fn format(self, format: impl AsRef<str>) -> String
Format the Date using the provided string.
assert_eq!(date!(2019-01-02).format("%Y-%m-%d"), "2019-01-02");sourcepub fn lazy_format(self, format: impl AsRef<str>) -> impl Display
pub fn lazy_format(self, format: impl AsRef<str>) -> impl Display
Format the Date using the provided string.
assert_eq!(date!(2019-01-02).lazy_format("%Y-%m-%d").to_string(), "2019-01-02");sourcepub fn parse(s: impl AsRef<str>, format: impl AsRef<str>) -> Result<Date, Error>
pub fn parse(s: impl AsRef<str>, format: impl AsRef<str>) -> Result<Date, Error>
Attempt to parse a Date using the provided string.
assert_eq!(
Date::parse("2019-01-02", "%F"),
Ok(date!(2019-01-02))
);
assert_eq!(
Date::parse("2019-002", "%Y-%j"),
Ok(date!(2019-002))
);
assert_eq!(
Date::parse("2019-W01-3", "%G-W%V-%u"),
Ok(date!(2019-W01-3))
);Trait Implementations
sourceimpl AddAssign<Duration> for Date
impl AddAssign<Duration> for Date
sourcefn add_assign(&mut self, duration: Duration)
fn add_assign(&mut self, duration: Duration)
Performs the += operation. Read more
sourceimpl AddAssign<Duration> for Date
impl AddAssign<Duration> for Date
sourcefn add_assign(&mut self, duration: Duration)
fn add_assign(&mut self, duration: Duration)
Performs the += operation. Read more
impl<'r> Decode<'r, MySql> for Date
impl<'r> Decode<'r, MySql> for Date
impl<'r> Decode<'r, Postgres> for Date
impl<'r> Decode<'r, Postgres> for Date
impl<'_> Encode<'_, MySql> for Date
impl<'_> Encode<'_, MySql> for Date
fn encode_by_ref(&self, buf: &mut Vec<u8, Global>) -> IsNull
fn encode_by_ref(&self, buf: &mut Vec<u8, Global>) -> IsNull
Writes the value of self into buf without moving self. Read more
fn size_hint(&self) -> usize
fn encode(self, buf: &mut <DB as HasArguments<'q>>::ArgumentBuffer) -> IsNull
fn encode(self, buf: &mut <DB as HasArguments<'q>>::ArgumentBuffer) -> IsNull
Writes the value of self into buf in the expected format for the database.
fn produces(&self) -> Option<<DB as Database>::TypeInfo>
impl<'_> Encode<'_, Postgres> for Date
impl<'_> Encode<'_, Postgres> for Date
fn encode_by_ref(&self, buf: &mut PgArgumentBuffer) -> IsNull
fn encode_by_ref(&self, buf: &mut PgArgumentBuffer) -> IsNull
Writes the value of self into buf without moving self. Read more
fn size_hint(&self) -> usize
fn encode(self, buf: &mut <DB as HasArguments<'q>>::ArgumentBuffer) -> IsNull
fn encode(self, buf: &mut <DB as HasArguments<'q>>::ArgumentBuffer) -> IsNull
Writes the value of self into buf in the expected format for the database.
fn produces(&self) -> Option<<DB as Database>::TypeInfo>
sourceimpl Ord for Date
impl Ord for Date
sourceimpl PartialOrd<Date> for Date
impl PartialOrd<Date> for Date
sourcefn partial_cmp(&self, other: &Date) -> Option<Ordering>
fn partial_cmp(&self, other: &Date) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl PgHasArrayType for Date
impl PgHasArrayType for Date
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
sourceimpl SubAssign<Duration> for Date
impl SubAssign<Duration> for Date
sourcefn sub_assign(&mut self, duration: Duration)
fn sub_assign(&mut self, duration: Duration)
Performs the -= operation. Read more
sourceimpl SubAssign<Duration> for Date
impl SubAssign<Duration> for Date
sourcefn sub_assign(&mut self, duration: Duration)
fn sub_assign(&mut self, duration: Duration)
Performs the -= operation. Read more
sourceimpl TryGetable for Date
impl TryGetable for Date
sourcefn try_get(res: &QueryResult, pre: &str, col: &str) -> Result<Self, TryGetError>
fn try_get(res: &QueryResult, pre: &str, col: &str) -> Result<Self, TryGetError>
Ensure the type implements this method
impl Type<MySql> for Date
impl Type<MySql> for Date
fn compatible(ty: &<DB as Database>::TypeInfo) -> bool
fn compatible(ty: &<DB as Database>::TypeInfo) -> bool
Determines if this Rust type is compatible with the given SQL type. Read more
impl Type<Postgres> for Date
impl Type<Postgres> for Date
fn compatible(ty: &<DB as Database>::TypeInfo) -> bool
fn compatible(ty: &<DB as Database>::TypeInfo) -> bool
Determines if this Rust type is compatible with the given SQL type. Read more
sourceimpl ValueType for Date
impl ValueType for Date
fn try_from(v: Value) -> Result<Date, ValueTypeErr>
fn type_name() -> String
fn column_type() -> ColumnType
fn unwrap(v: Value) -> Self
impl Copy for Date
impl Eq for Date
impl StructuralEq for Date
impl StructuralPartialEq for Date