Error types returned by SeaORM operations.
Structs
- Column
From StrErr - Error during
impl FromStr for Entity::Column - Sqlx
MySql Error sqlx-mysql - An error returned from the MySQL database.
- Sqlx
Postgres Error sqlx-postgres - An error returned from the PostgreSQL database.
- Sqlx
Sqlite Error sqlx-sqlite
Enums
- Conn
Acquire Err - Connection Acquire error
- DbErr
- An error from unsuccessful database operations
- Runtime
Err - Runtime error
- SqlErr
- A portable, backend-agnostic classification of the most common SQL
constraint violations, produced by
DbErr::sql_err. - Sqlx
Error sqlx-dep - Represents all the ways a method can fail within SQLx.
- TryGet
Error - An error from trying to get a row from a Model