#[non_exhaustive]pub struct DatabaseConnection {
pub inner: DatabaseConnectionType,
/* private fields */
}Expand description
A handle to a database — implements ConnectionTrait
and TransactionTrait so it works with every
query and mutation method in SeaORM.
Behind the scenes this is a connection pool (for SQLx-backed drivers) or
a shared connection (for rusqlite / mocks / proxies), so it is cheap
to clone — pass &DbConn around or db.clone() into spawned tasks.
Obtain one via Database::connect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inner: DatabaseConnectionTypeDriver-specific connection or pool. Held in a field so we can attach orthogonal state (e.g. RBAC) alongside.
Implementations
Sourceimpl DatabaseConnection
impl DatabaseConnection
Sourcepub fn as_mock_connection(&self) -> &MockDatabaseConnection
Available on crate feature mock only.
pub fn as_mock_connection(&self) -> &MockDatabaseConnection
mock only.Sourcepub fn into_transaction_log(self) -> Vec<Transaction>
Available on crate feature mock only.
pub fn into_transaction_log(self) -> Vec<Transaction>
mock only.Get the transaction log as a collection Vec<crate::Transaction>
Panics
Panics if the mocker mutex is being held by another thread.
Sourceimpl DatabaseConnection
impl DatabaseConnection
Sourcepub fn as_proxy_connection(&self) -> &ProxyDatabaseConnection
Available on crate feature proxy only.
pub fn as_proxy_connection(&self) -> &ProxyDatabaseConnection
proxy only.Sourceimpl DatabaseConnection
impl DatabaseConnection
Sourcepub fn load_rbac(&self) -> Result<(), DbErr>
Available on crate feature rbac only.
pub fn load_rbac(&self) -> Result<(), DbErr>
rbac only.Load RBAC data from the same database as this connection and setup RBAC engine. If the RBAC engine already exists, it will be replaced.
Sourcepub fn load_rbac_from(&self, db: &DbConn) -> Result<(), DbErr>
Available on crate feature rbac only.
pub fn load_rbac_from(&self, db: &DbConn) -> Result<(), DbErr>
rbac only.Load RBAC data from the given database connection and setup RBAC engine. This could be from another database.
Sourcepub fn replace_rbac(&self, engine: RbacEngine)
Available on crate feature rbac only.
pub fn replace_rbac(&self, engine: RbacEngine)
rbac only.Replace the internal RBAC engine.
Sourcepub fn restricted_for(
&self,
user_id: RbacUserId,
) -> Result<RestrictedConnection, DbErr>
Available on crate feature rbac only.
pub fn restricted_for( &self, user_id: RbacUserId, ) -> Result<RestrictedConnection, DbErr>
rbac only.Create a restricted connection with access control specific for the user.
Sourceimpl DatabaseConnection
impl DatabaseConnection
Sourcepub fn transaction<F, T, E>(
&self,
callback: F,
) -> Result<T, TransactionError<E>>
pub fn transaction<F, T, E>( &self, callback: F, ) -> Result<T, TransactionError<E>>
Execute the function inside a transaction. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub fn transaction_with_config<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>
pub fn transaction_with_config<F, T, E>( &self, callback: F, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<T, TransactionError<E>>
Execute the function inside a transaction with isolation level and/or access mode. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub fn get_database_backend(&self) -> DbBackend
pub fn get_database_backend(&self) -> DbBackend
Sourcepub fn get_schema_builder(&self) -> SchemaBuilder
pub fn get_schema_builder(&self) -> SchemaBuilder
Creates a SchemaBuilder for this backend
Sourcepub fn set_metric_callback<F>(&mut self, _callback: F)
pub fn set_metric_callback<F>(&mut self, _callback: F)
Sets a callback to metric this connection
Sourcepub fn close(self) -> Result<(), DbErr>
pub fn close(self) -> Result<(), DbErr>
Explicitly close the database connection.
See Self::close_by_ref for usage with references.
Sourcepub fn close_by_ref(&self) -> Result<(), DbErr>
pub fn close_by_ref(&self) -> Result<(), DbErr>
Explicitly close the database connection