pub struct DatabaseTransaction { /* private fields */ }Expand description
A live database transaction.
Obtain one with
TransactionTrait::begin (manual
commit/rollback) or
TransactionTrait::transaction
(auto commit on Ok, auto rollback on Err). Like
DatabaseConnection it implements
ConnectionTrait, so SeaORM’s query and
mutation methods work against it transparently. Calling begin on a
transaction starts a nested transaction via SAVEPOINT.
Implementations
Sourceimpl DatabaseTransaction
impl DatabaseTransaction
Sourcepub fn transaction<F, T, E>(
&self,
callback: F,
) -> Result<T, TransactionError<E>>
pub fn transaction<F, T, E>( &self, callback: F, ) -> Result<T, TransactionError<E>>
Execute the function inside a transaction. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub fn transaction_with_config<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>
pub fn transaction_with_config<F, T, E>( &self, callback: F, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<T, TransactionError<E>>
Execute the function inside a transaction with isolation level and/or access mode. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.