Struct sea_orm::DatabaseTransaction [−][src]
pub struct DatabaseTransaction { /* fields omitted */ }Expand description
Defines a database transaction, whether it is an open transaction and the type of backend to use
Implementations