RestrictedTransaction

Struct RestrictedTransaction 

pub struct RestrictedTransaction { /* private fields */ }
Available on crate feature rbac only.
Wrapper of DatabaseTransaction that performs authorization on all executed queries for the current user. Note that raw SQL Statement is not allowed currently.

Implementations

Source

impl RestrictedTransaction

pub fn user_id(&self) -> UserId

Get the [RbacUserId] bounded to this connection.

pub async fn transaction_async<F, T, E>( &self, callback: F, ) -> Result<T, TransactionError<E>>
where F: for<'c> AsyncFnOnce(&'c RestrictedTransaction) -> Result<T, E> + Send, T: Send, E: Display + Debug + Send,

Execute the function inside a transaction. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.

pub async fn transaction_with_config_async<F, T, E>( &self, callback: F, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<T, TransactionError<E>>
where F: for<'c> AsyncFnOnce(&'c RestrictedTransaction) -> Result<T, E> + Send, T: Send, E: Display + Debug + Send,

Execute the function inside a transaction with isolation level and/or access mode. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.

pub fn user_can_run<S: StatementBuilder>(&self, stmt: &S) -> Result<(), DbErr>

Returns () if the current user can execute / query the given SQL statement. Returns DbErr::AccessDenied otherwise.

pub fn user_can<P, R>(&self, permission: P, resource: R) -> Result<bool, DbErr>

Returns true if the current user can perform action on resource

Source

impl RestrictedTransaction

pub async fn commit(self) -> Result<(), DbErr>

Commit a transaction

pub async fn rollback(self) -> Result<(), DbErr>

Rolls back a transaction explicitly