pub struct RestrictedTransaction { /* private fields */ }rbac only.Expand description
Wrapper of DatabaseTransaction that performs authorization on all executed
queries for the current user. Note that raw SQL Statement is not allowed
currently.
Implementations
Sourceimpl RestrictedTransaction
impl RestrictedTransaction
Sourcepub async fn transaction_async<F, T, E>(
&self,
callback: F,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c RestrictedTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
pub async fn transaction_async<F, T, E>(
&self,
callback: F,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c RestrictedTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
Execute the function inside a transaction. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub async fn transaction_with_config_async<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c RestrictedTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
pub async fn transaction_with_config_async<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>where
F: for<'c> AsyncFnOnce(&'c RestrictedTransaction) -> Result<T, E> + Send,
T: Send,
E: Display + Debug + Send,
Execute the function inside a transaction with isolation level and/or access mode. If the function returns an error, the transaction will be rolled back. Otherwise, the transaction will be committed.
Sourcepub fn user_can_run<S: StatementBuilder>(&self, stmt: &S) -> Result<(), DbErr>
pub fn user_can_run<S: StatementBuilder>(&self, stmt: &S) -> Result<(), DbErr>
Returns () if the current user can execute / query the given SQL statement.
Returns DbErr::AccessDenied otherwise.